# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ascii_art']

package_data = \
{'': ['*']}

install_requires = \
['Pillow>=8.1.2,<9.0.0']

entry_points = \
{'console_scripts': ['ascii-art = ascii_art.__main__:main']}

setup_kwargs = {
    'name': 'ascii-art-cli',
    'version': '1.4.0',
    'description': 'ASCII art generator with multiple customization parameters',
    'long_description': '# ![ascii-art](https://raw.githubusercontent.com/dawsonbooth/ascii-art/master/logo.png)\n\n[![pypi version](https://img.shields.io/pypi/v/ascii-art-cli.svg?style=flat)](https://pypi.org/pypi/ascii-art-cli/)\n[![downloads](https://pepy.tech/badge/ascii-art-cli)](https://pepy.tech/project/ascii-art-cli)\n[![build status](https://github.com/dawsonbooth/ascii-art/workflows/build/badge.svg)](https://github.com/dawsonbooth/ascii-art/actions?workflow=build)\n[![python versions](https://img.shields.io/pypi/pyversions/ascii-art-cli.svg?style=flat)](https://pypi.org/pypi/ascii-art-cli/)\n[![format](https://img.shields.io/pypi/format/ascii-art-cli.svg?style=flat)](https://pypi.org/pypi/ascii-art-cli/)\n[![license](https://img.shields.io/pypi/l/ascii-art-cli.svg?style=flat)](https://github.com/dawsonbooth/ascii-art/blob/master/LICENSE)\n\n## Description\n\nNamed as such, this package is a command-line ASCII art generator written in Python. There is a variety of parameters which are detailed below.\n\n## Installation\n\nWith Python installed, install the package from PyPI with the following command:\n\n```bash\npython -m pip install ascii-art-cli\n```\n\nThis package is not to be confused with [ascii_art](https://pypi.org/project/ascii_art/) or other various ASCII art packages.\n\n## Usage\n\nThis is a command-line program, and can be executed as follows:\n\n```bash\nascii-art [-h] [--width WIDTH] [--height HEIGHT] [--chars CHARS] [--font FONT] [--invert] [--normalize] input\n```\n\nPositional arguments:\n\n```txt\n  input            Path to image from which ASCII art will be generated\n```\n\nOptional arguments:\n\n```txt\n  -h, --help       show this help message and exit\n  --width WIDTH    Character width of ASCII art\n  --height HEIGHT  Character height of ASCII art\n  --chars CHARS    String containing characters to be seen in ASCII art\n  --font FONT      Font for calculating the character weights\n  --invert         Whether the ASCII output color is inverted\n  --normalize      Whether the weights of the provided ASCII characters are normalized\n```\n\nExample:\n\n```bash\nascii-art examples/images/einstein.jpg --width 100 --height 50 --font "Courier" --invert --normalize\n```\n\n```txt\n,;+;;+;;;,?;?;;;,,,,,,;,;\',,\'\',;%S;;;%SS%SSSSSSSSSSSSSSSSSSSSSSSSS%%%%%%??%%%%;\'S+..    .          .\n+;;;?;+;,++;;,,,,,;,,,,,,,,,\';+%S,,%S%SS#SSSSSS####S#S##S##SSSSSSS%S%%%%%%%S%SS+\'%\'.\n?+;;,;+;;,;+;;;,,,,;,,,\',\'\',;%%%\',S%S%SSSSSS#SSSS#SSSSS####SSS#SSSSS%S%%S%%%%S%%%;;\'.            ..\n%+;%+;?++;;,,;,,,,,,\',,\',,;+,%?;\'?;%SSSSS#SSSSS##SS######@##SSSS#SSSS%S%S%%%%%S%%\'%\'\'        .... .\n?????;;??;;;+,,+,,,,\'\'\',;+;;;;;\',%%%SSS#######S###########SSS##SSSSSSS%SS%%%%SSS%?\',;,   .    ...\n?+;??++;;+;;;,,,,,\'\'\',,;%?%%,,\'\'%,%SSSS#######S#####@#######SSS%#SSSSSS%%%%%%SSSS%;?.\'\'\'.          .\n;?%;;;+;;+;,,,,,,\'\'\',;S?;,\',;,\'+,S%?%SSS#@###SS########@#SSSS#SSSSSSSS%SS%%%%S%S%S?%\'  .\'    .\n???;;;++,;+;,;\',\'\'\',%S\'?;,+,,?.;?%S%%SSS#@############S###SSSSSSSSSSSSSSSS%%SSSSS%+,,.. \',    .\n??+?;;%++;;,,,,,,;\';%\',,;;;\';%\';%\'.\',+,SSS###SSS##SSS%,\',SS%S#%SSSSSSSSSSS%SS%SS%%%,;,.  .\'\n%;+;?+;+;;;+,,,,,\'\'?\'\'?;?+,;%?.\'\'.\'\',%SS##S#SSS##SSSSSS?;,;%??SSSSSSSSSSSSSSSSSSS%?%;\'+\'..\'.\nS????;;;;;;;;;,\'\',,%,;+,%?,,%;\'%;;%%%%SSS##@SSS##SS###SSSSSSSSSSSSS%SSSSSS%SSSSSS%?+;,\'\'.\'.\'\n?,?+;;?;;;,,;,,,\'+,\'\'.%%;,,?%+.;?SSSSS%SSS#S#@###@####S##SSSSSSSS%SSSSSSSSSSSSS%%%????\'\',. .\'..    .\n,S;,;;??;;;;,\',,\'\'\',.,,%;\'\';%,.%%SS%%%S%%SS####@@#SS#SS#SSSS#SSSSSSSSSSSSSS%SSS%%%%,;?;+.,   .\n%%?;;+%;;;+,,,\',.,...,;;,\',;?\',%SS%%%??SS?%S#@@###SSSS%%+,;%SS#SSS%SSSSSSSSSSSSSSS%%,,+?;,,.   .\nS?%;+;+;,,,,,\';\'.\'.\'\',%,,,\'+%\'\'?S%,,?+?S%%,?S#@#S#SSSSS?+%%%+%SSSS%SSSSSSSSSSSSSSS%%%;?;%%\' .\nS,+,;;;+,,,,\'\'......\',%\'\'\',;?\',%?,\'##;,?;S?\'S@##SSS%%%;\';.,S%%SSSS%SSSSS%SSSSSSSSS%S?;%;%;,S.      .\n%%?;+,;,;,\'\'.\'......\'\'%\',\',%,\';%%\'+S...;#%%\'S#SSS%SS%?#S...,?%%SSS%SSS%S%SSSSSSSS%+%%?;;%%;,\';\n,+?;;,;,,\'\'\'\'.... ..\',?,\'\'\'%\'\';%S,;%,\'%%;%,%SSSSS%#S%SSS...S%SSSSSSSSSS%SSSSSSS%S%%%??%?;+;;..,.\n,%\';,,;,\'\'\'\'......\';.\';.\',.;\'\';%,;\'\'%?S;SS\'%SSSSS%SS%%%?%%%?+%SSSSSSSSS%%%SSSS%%%%%?%;?%%;,++  ;\n%%\',\';;,\',\'\'....\'.., ;%.\'\'.;.,+,?%?,%%%%%,,%SSSSSSSS?%S%%%%%%%S%%SSS%SSS%%SSSS%%%%%%%%%,%;;,;;\nS%\',,\'.;\'\'\'\'...,.....;,\'\'\'.\'.,%;%%%%%%%%?\';SSS%SSSSSSS%%SSSSSS%%SSSS%SS%%%%S%%%%;;;%%%%%+S?\'+,\' \'\n%;..\'\'\'\'\',\'....\'....,.,\'.\'...?%%%SSSS%SS\'\'%SS%%%SSSS#SS#SSSSSSSS%%S%%%S%%%%%%%??S%\',+%%%%?%+\'+.. .\n%,. ...\'\'.\'\'...\'...;\'\',..S...,%SSSSSSSS%\'%SSSS%?%SSS###SSSSSSSSSSSSS%%%%%%%%%%;%%S;%;;%%%%%%%?,. \'\n+\'  ....\'\'......\'.?,\'\'...,...%S#SS?SSS%,+SSSS%%%%SS#SS#S@#SSSS##SSS%%%%%%++;%?%SS%;?;.%%SSS%%?;\'\'..\n?.  .  .........\'.\'\'.....\'...%SSSS%SS%S,SS##SSS%?%S##SS########SSSSS%%%%%+;%;SSSSSS.%%%%SSS%;%%\',.\n,. ... ........\'... ...\'\'\'...;#SS%SS%#\';SS##@SS%%%%SS@@#S####S##SSS%%+%%?;,%%SSSS%%S%S.%SSSS%%S+\'.\n.... .. . .........\'..\'...\'..+%S%%%S#S,,%S#@#SS%SS%%SS@#####S##SS#SS?;%%%;;%S#SSS%SS%S%;SSSS%?S%\' .\n?, ....  .... ....\'.......,..;?%%SS##\',\',SSSSS%SSSS?S#S##@#S#S#SSSSS%;%%?%++%%%SS%%SS%%;S#SS,%S%;.\'.\n,,.... . ..  .. .........,,..++;%S##SS?\'.;%%%;#S@%%%SSSS####SSSSS+SS%?%%?%;%S#%S%S%SS%%+SSSS;;S%?.\n%;.. ....   .. ... ..%\'+S\'\'..+%;SSSS%%?SSSS#SS#%S%SSSS#S%S#SSSSSSSSS+?%+%%;SSS%S;SSS%S;S#SSS?+S;\'\'.\n;,  %#... .S.  ..... .. \'\'\'..%S;%SSSSSSS#S#S%SS#SSSS%SSSSSSSSSSSSSSS%%%%%%,SSS?;??%S%%%SSSSS,,%, \'..\n\',   .........  ... .  .,\'\'..%S;S%S%SS@@SSSS%S##S#S#SSSSSSSSSSSSSSSS+%%?%?+SSS%,%%%?%+SS%S%%,%; \' ..\n,\' .   . .  ....... .....\'...;S,%,?SS%S#%S#SS#SSSS##%SSSSS+SSSSSSSS%;%%%%+%SS%??.\'S%%%%;;SS%,\'......\n\'   ...#.  .. .  .. .....\'...,%;%?;;%%%SS#SSSS%S#%%%S%SSSSSSSSSSSSS%,S%%%;.S%?\' ..;S;,%.\'%,. .......\n\'  . . ......  .... .........\'%;%%?,\',,?;%;%++S%,,%,?S%#SS%SSSSSSSS%?%S%%%\'        .\'.  .;\'.........\n.  ..  . ...   ...............%%%SS;,.\'.,\'?\';,,+SS,\'+,;\'SSSSSSSSSSS%;SS%+,\'            . ...........\n   ..   ..  ....... ..........%%\'SSS%,,,?;%%?%%%%%;%,..;;SSS#SSSSSS%,SS%+\'        .   . ......\'....\'\n        . ..... ...............+%;SSS?.%S%%S%S%%%%%?\'\'++%%?SSSSSSSS?SS%,           . ... .....\'..\',,\n     .    . .  .......\'........%S,SS#%.%%%%%%%S%S%?,,%SS#%?SS%SSSSS,S%,         .. ..... .......\'\',,\n         .......................%S?##S.S#%S%S%%;SS;%%%%SSS%SS%SSSS+SS.              ... ....\'. \'\'+,\'\n       . . ... ........\'........\'S+S#S.;SS%%;%%+#,,+?%S#SS%S%%SSSS%S  .       .   ...  .......\',+,\';\n            ..\'..................;SS#S.+S#SS%;;%S;,,%SSS#SSS?S#S%,%.       .   . .... ..... .,\'+,,\',\n          \',,\'\'\'\'..........\'......S\'#S.\'%@S%%?;%%\';%S%SSSSSS;SS%+. .  .  .  .   .  .. . ....,,;,\';,,\n      . ,,,,,,\',\'............\'....\'SSS,.%SS+%%%S;%S%SS##SS#SS#S?...      .. .  .... ..... \',;,,\';,\',\n      ,,,\',,,,,\'\'\'..........\'\'\'....%,SS.;%S%%?S%;%SS#S###SS%SS\'..   ..   . .  . .   .   .\'\',++,;,;;,\n    ,,,,,,,,,,,\',.\'.........\'\'\'\'....\'?S%.?%?S%?,SS#SSS###SSSS....  ...   .. ..... .. ...\';+%?,;,\'\',\'\n. ,,,;,,,,,,,,,,,\'\'\'...\'\'\'\'\'\'\'\'\'\'.....?S..%%%%%S##SSSS#S#S%........     .  .......   ..,,,,\',;,;\'\'\'.\n\',,,,,,,,,,\',,,,,\',\'....\'\'\'\'\'\'\'\'\'......%%..;+;SS@S#SSSSSS,.................... ...   \'\'\',,,\',;;+\',..\n,,,,,;,,,,,\',,;,,,\'\'\'.\'\'.\'\'\'\'\'\'\'\'\'......%%+,%####S####S%............ ...........   .\'\',;;;\'+,;\';\'\'..\n,;,,,;,,,,,,;,,,;,,\'\'.\'\'\'\'\'\'\'\'\'..\'\'......?%SSSSSS#SSS%............ ....\'........  ..,,,,\',,%;,\'\'\'..\'\n```\n\nBy default, the command will output the generated ASCII art to the console. If instead you would like to output to a file, feel free to use the redirection `>` operator. More info on that [here](https://linuxcommand.org/lc3_lts0070.php).\n\nFeel free to [check out the docs](https://dawsonbooth.github.io/ascii-art/) for more information on how to use this package.\n\n## License\n\nThis software is released under the terms of [MIT license](LICENSE).\n',
    'author': 'Dawson Booth',
    'author_email': 'pypi@dawsonbooth.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/dawsonbooth/ascii-art',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
